@@ -1,6 +1,6 @@
 /*
  * This file is part of the KDE Akonadi Search Project
- * SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  *
@@ -19,12 +19,10 @@
 
 using namespace Akonadi::Search::PIM;
 
-class Q_DECL_HIDDEN NoteQuery::Private
+class Akonadi::Search::PIM::NoteQueryPrivate
 {
 public:
-    Private()
-    {
-    }
+    NoteQueryPrivate() = default;
 
     QString title;
     QString note;
@@ -33,14 +31,11 @@ public:
 
 NoteQuery::NoteQuery()
     : Query()
-    , d(new Private)
+    , d(new NoteQueryPrivate)
 {
 }
 
-NoteQuery::~NoteQuery()
-{
-    delete d;
-}
+NoteQuery::~NoteQuery() = default;
 
 void NoteQuery::matchTitle(const QString &title)
 {
@@ -71,16 +66,16 @@ ResultIterator NoteQuery::exec()
         db = Xapian::Database(QFile::encodeName(dir).toStdString());
     } catch (const Xapian::DatabaseOpeningError &) {
         qCWarning(AKONADI_SEARCH_PIM_LOG) << "Xapian Database does not exist at " << dir;
-        return ResultIterator();
+        return {};
     } catch (const Xapian::DatabaseCorruptError &) {
         qCWarning(AKONADI_SEARCH_PIM_LOG) << "Xapian Database corrupted";
-        return ResultIterator();
+        return {};
     } catch (const Xapian::DatabaseError &e) {
         qCWarning(AKONADI_SEARCH_PIM_LOG) << "Failed to open Xapian database:" << QString::fromStdString(e.get_error_string());
-        return ResultIterator();
+        return {};
     } catch (...) {
         qCWarning(AKONADI_SEARCH_PIM_LOG) << "Random exception, but we do not want to crash";
-        return ResultIterator();
+        return {};
     }
 
     QList<Xapian::Query> m_queries;
@@ -121,6 +116,6 @@ ResultIterator NoteQuery::exec()
         return iter;
     } catch (const Xapian::Error &e) {
         qCWarning(AKONADI_SEARCH_PIM_LOG) << QString::fromStdString(e.get_type()) << QString::fromStdString(e.get_description());
-        return ResultIterator();
+        return {};
     }
 }
